@@ -5,6 +5,7 @@ from typing import Sequence
 
 from dexp.datasets.clearcontrol_dataset import CCDataset
 from dexp.datasets.joined_dataset import JoinedDataset
+from dexp.datasets.tiff_dataset import TIFDataset
 from dexp.datasets.zarr_dataset import ZDataset
 
 
@@ -20,10 +21,15 @@ def glob_datasets(glob_paths: Sequence[str]):
     -------
 
     """
+    if len(glob_paths) == 0:
+        raise ValueError("No dataset path provided.")
 
     # Apply glob:
     paths = tuple(glob.glob(glob_path) for glob_path in glob_paths)
 
+    if len(paths) == 0:
+        raise ValueError("Could not find any dataset with provided paths", glob_paths)
+
     # concatenate list of paths:
     paths = reduce(lambda u, v: u + v, paths)
 
@@ -83,6 +89,8 @@ def open_dataset(path: str):
     if path.endswith(".zarr.zip") or path.endswith(".zarr"):
         # we can recognise a Zarr dataset by its extension.
         dataset = ZDataset(path)
+    elif path.endswith("tif") or path.endswith("tiff"):
+        dataset = TIFDataset(path)
     elif exists(join(path, "stacks")):
         # we can recognise a ClearControl dataset by the presence of a 'stacks' sub folder.
         dataset = CCDataset(path)
