@@ -1,6 +1,5 @@
-import math
 import tempfile
-from os.path import join
+from pathlib import Path
 
 from arbol import aprint, asection
 
@@ -8,7 +7,7 @@ from dexp.datasets import ZDataset
 from dexp.datasets.operations.deskew import dataset_deskew
 from dexp.datasets.synthetic_datasets import generate_nuclei_background_data
 from dexp.optics.psf.standard_psfs import nikon16x08na
-from dexp.processing.filters.fft_convolve import fft_convolve
+from dexp.processing.deskew import skew
 from dexp.utils.backends import Backend, CupyBackend, NumpyBackend
 
 
@@ -27,9 +26,8 @@ def demo_deskew_cupy():
         return False
 
 
-def _demo_deskew(length=96, zoom=1, shift=1, display=True):
+def _demo_deskew(length=96, zoom=1, shift=1, angle=45, display=True):
     xp = Backend.get_xp_module()
-    sp = Backend.get_sp_module()
 
     with asection("prepare simulated timelapse:"):
         # generate nuclei image:
@@ -45,68 +43,51 @@ def _demo_deskew(length=96, zoom=1, shift=1, display=True):
             dtype=xp.float32,
         )
 
-        # Pad:
-        pad_width = (
-            (int(shift * zoom * length // 2), int(shift * zoom * length // 2)),
-            (0, 0),
-            (0, 0),
-        )
-        image = xp.pad(image, pad_width=pad_width)
-
-        # Add blur:
-        psf = nikon16x08na()
-        psf = psf.astype(dtype=image.dtype, copy=False)
-        image = fft_convolve(image, psf)
-
-        # apply skew:
-        angle = 45
-        matrix = xp.asarray(
-            [[math.cos(angle * math.pi / 180), math.sin(angle * math.pi / 180), 0], [0, 1, 0], [0, 0, 1]]
-        )
-        offset = 0 * xp.asarray([image.shape[0] // 2, 0, 0])
-        # matrix = xp.linalg.inv(matrix)
-        skewed = sp.ndimage.affine_transform(image, matrix, offset=offset)
-
-        # Add noise and clip
-        # skewed += xp.random.uniform(-1, 1)
-        skewed = xp.clip(skewed, a_min=0, a_max=None)
-
-        # cast to uint16:
-        skewed = skewed.astype(dtype=xp.uint16)
-
+        skewed = skew(image, nikon16x08na(), shift=shift, angle=angle, zoom=zoom, axis=0)
         # Single timepoint:
         skewed = skewed[xp.newaxis, ...]
 
     with tempfile.TemporaryDirectory() as tmpdir:
         aprint("created temporary directory", tmpdir)
+        tmpdir = Path(tmpdir)
 
         with asection("Prepare dataset..."):
-            input_path = join(tmpdir, "dataset.zarr")
-            dataset = ZDataset(path=input_path, mode="w", store="dir")
+            input_path = tmpdir / "dataset.zarr"
+            input_dataset = ZDataset(path=input_path, mode="w", store="dir")
 
-            dataset.add_channel(name="channel", shape=skewed.shape, chunks=(1, 64, 64, 64), dtype=skewed.dtype)
+            input_dataset.add_channel(name="channel", shape=skewed.shape, chunks=(1, 64, 64, 64), dtype=skewed.dtype)
 
-            dataset.write_array(channel="channel", array=Backend.to_numpy(skewed))
+            input_dataset.write_array(channel="channel", array=Backend.to_numpy(skewed))
 
-            source_array = dataset.get_array("channel")
+            source_array = input_dataset.get_array("channel")
 
         with asection("Deskew..."):
             # output_folder:
-            output_path = join(tmpdir, "deskewed.zarr")
+            output_path = tmpdir / "deskewed.zarr"
+            output_dataset = ZDataset(path=output_path, mode="w")
 
             # deskew:
             dataset_deskew(
-                dataset=dataset,
-                dest_path=output_path,
+                input_dataset=input_dataset,
+                output_dataset=output_dataset,
                 channels=("channel",),
-                slicing=(slice(0, 1),),
+                # slicing=(slice(0, 1),),
+                mode="yang",
                 dx=1,
                 dz=1,
                 angle=angle,
+                flips=(False,),
+                camera_orientation=0,
+                depth_axis=0,
+                lateral_axis=1,
+                padding=False,
+                devices=[
+                    0,
+                ],
             )
 
-            deskew_dataset = ZDataset(path=output_path, mode="a")
-            deskew_array = deskew_dataset.get_array("channel")
+            output_dataset = ZDataset(path=output_path, mode="r")
+            deskew_array = output_dataset.get_array("channel")
 
             assert deskew_array.shape[0] == 1
 
