@@ -1,10 +1,8 @@
 import numpy
 from skimage.data import camera
 
-from dexp.processing.backends.backend import Backend
-from dexp.processing.backends.cupy_backend import CupyBackend
-from dexp.processing.backends.numpy_backend import NumpyBackend
 from dexp.processing.interpolation.warp import warp
+from dexp.utils.backends import Backend, CupyBackend, NumpyBackend
 from dexp.utils.timeit import timeit
 
 
@@ -38,15 +36,17 @@ def _demo_warp_2d(grid_size=8):
         dewarped = warp(warped, -vector_field, vector_field_upsampling=4)
 
     from napari import Viewer, gui_qt
+
     with gui_qt():
+
         def _c(array):
             return Backend.to_numpy(array)
 
         viewer = Viewer()
-        viewer.add_image(_c(image), name='image')
-        viewer.add_image(_c(vector_field), name='vector_field')
-        viewer.add_image(_c(warped), name='warped')
-        viewer.add_image(_c(dewarped), name='dewarped')
+        viewer.add_image(_c(image), name="image")
+        viewer.add_image(_c(vector_field), name="vector_field")
+        viewer.add_image(_c(warped), name="warped")
+        viewer.add_image(_c(dewarped), name="dewarped")
 
 
 if __name__ == "__main__":
