@@ -1,18 +1,19 @@
 import numpy
 from scipy.ndimage import zoom
 
-from dexp.processing.backends.backend import Backend
-from dexp.processing.backends.numpy_backend import NumpyBackend
 from dexp.utils import xpArray
+from dexp.utils.backends import Backend, NumpyBackend
 
 
-def warp(image: xpArray,
-         vector_field: xpArray,
-         vector_field_upsampling: int = 2,
-         vector_field_upsampling_order: int = 1,
-         mode: str = 'border',
-         image_to_backend: bool = False,
-         internal_dtype=None):
+def warp(
+    image: xpArray,
+    vector_field: xpArray,
+    vector_field_upsampling: int = 2,
+    vector_field_upsampling_order: int = 1,
+    mode: str = "border",
+    image_to_backend: bool = False,
+    internal_dtype=None,
+):
     """
     Applies a warp transform (piece wise linear or constant) to an image based on a vector field.
     Only implemented for 1d, 2d, and 3d images.
@@ -21,17 +22,20 @@ def warp(image: xpArray,
     ----------
     image : image to warp
 
-    vector_field : vector field to warp inoput image with. The vector field is an array of dimension n+1 where n is the dimension of the input image.
-    The first n dimensions can be of arbirary lengths, and the last vector is the warp vector for each image region that the first
+    vector_field : vector field to warp inoput image with. The vector field is an array of
+        dimension n+1 where n is the dimension of the input image.
+    The first n dimensions can be of arbirary lengths, and the last vector is the warp vector
+        for each image region that the first
 
     vector_field_upsampling : upsampling factor for teh vector field (best use a power of two)
 
     vector_field_upsampling_order : upsampling order: 0-> nearest, 1->linear, 2->quadratic, ... (uses scipy zoom)
 
-    mode : How to handle warping that reaches outside of the image bounds, can be: 'clamp', 'border', 'wrap', 'mirror'
+    mode : How to handle warping that reaches outside of the image bounds,
+        can be: 'clamp', 'border', 'wrap', 'mirror'
 
-    image_to_backend : By default one can directly copy a numpy array to texture memory,
-    if needed, this option let's one first more the data to a cupy array before moving to texture memory. Not recommended.
+    image_to_backend : By default one can directly copy a numpy array to texture memory, if needed,
+    this option let's one first more the data to a cupy array before moving to texture memory. Not recommended.
 
     internal_dtype : internal dtype. Right now the dtype must be float32 because of CUDa texture dtype limitations.
 
@@ -56,7 +60,9 @@ def warp(image: xpArray,
         # Note: unfortunately numpy does support float16 zooming, and cupy does not support high-order zooming...
         vector_field = Backend.to_numpy(vector_field, dtype=numpy.float32)
         if image.ndim > 1:
-            vector_field = zoom(vector_field, zoom=(vector_field_upsampling,) * image.ndim + (1,), order=vector_field_upsampling_order)
+            vector_field = zoom(
+                vector_field, zoom=(vector_field_upsampling,) * image.ndim + (1,), order=vector_field_upsampling_order
+            )
         else:
             vector_field = zoom(vector_field, zoom=(vector_field_upsampling,), order=vector_field_upsampling_order)
 
@@ -66,7 +72,8 @@ def warp(image: xpArray,
     image = image.astype(dtype=internal_dtype, copy=False)
     vector_field = Backend.to_backend(vector_field, dtype=internal_dtype)
 
-    from dexp.processing.backends.cupy_backend import CupyBackend
+    from dexp.utils.backends import CupyBackend
+
     if type(Backend.current()) is NumpyBackend:
         raise NotImplementedError("Warping not yet implemented for the Numpy backend.")
 
@@ -75,12 +82,15 @@ def warp(image: xpArray,
         params = (image, vector_field, mode)
         if image.ndim == 1:
             from dexp.processing.interpolation._cupy.warp_1d import _warp_1d_cupy
+
             result = _warp_1d_cupy(*params)
         elif image.ndim == 2:
             from dexp.processing.interpolation._cupy.warp_2d import _warp_2d_cupy
+
             result = _warp_2d_cupy(*params)
         elif image.ndim == 3:
             from dexp.processing.interpolation._cupy.warp_3d import _warp_3d_cupy
+
             result = _warp_3d_cupy(*params)
         else:
             raise NotImplementedError("Warping for ndim>3 not implemented.")
