@@ -1,4 +1,4 @@
-from dexp.utils.backends.backend import Backend
+from dexp.utils.backends.backend import Backend, dispatch_data_to_backend
 from dexp.utils.backends.best_backend import BestBackend
 from dexp.utils.backends.cupy_backend import CupyBackend
 from dexp.utils.backends.numpy_backend import NumpyBackend
