@@ -1,9 +1,10 @@
+import importlib
 import threading
 import types
 from abc import ABC, abstractmethod
-from typing import Any
+from typing import Any, Dict, Iterable, List, Optional, Tuple
 
-import numpy
+import numpy as np
 
 from dexp.utils import xpArray
 
@@ -62,7 +63,7 @@ class Backend(ABC):
         Backend._local.backend_stack.append(backend)
 
     @staticmethod
-    def to_numpy(array: xpArray, dtype=None, force_copy: bool = False) -> numpy.ndarray:
+    def to_numpy(array: xpArray, dtype=None, force_copy: bool = False) -> np.ndarray:
         return Backend.current()._to_numpy(array, dtype=dtype, force_copy=force_copy)
 
     @staticmethod
@@ -70,13 +71,17 @@ class Backend(ABC):
         return Backend.current()._to_backend(array, dtype=dtype, force_copy=force_copy)
 
     @staticmethod
-    def get_xp_module(array: xpArray = None) -> Any:
+    def get_xp_module(array: Optional[xpArray] = None) -> types.ModuleType:
         return Backend.current()._get_xp_module(array)
 
     @staticmethod
-    def get_sp_module(array: xpArray = None) -> Any:
+    def get_sp_module(array: Optional[xpArray] = None) -> types.ModuleType:
         return Backend.current()._get_sp_module(array)
 
+    @staticmethod
+    def get_skimage_submodule(submodule: str, array: Optional[xpArray] = None) -> types.ModuleType:
+        return Backend.current()._get_skimage_submodule(submodule, array)
+
     def __enter__(self):
         if not hasattr(Backend._local, "backend_stack"):
             Backend._local.backend_stack = []
@@ -101,7 +106,7 @@ class Backend(ABC):
         self.clear_memory_pool()
 
     @abstractmethod
-    def _to_numpy(self, array: xpArray, dtype=None, force_copy: bool = False) -> numpy.ndarray:
+    def _to_numpy(self, array: xpArray, dtype=None, force_copy: bool = False) -> np.ndarray:
         """Converts backend array to numpy. If array is already a numpy array it is returned unchanged.
 
         Parameters
@@ -129,8 +134,7 @@ class Backend(ABC):
         """
         raise NotImplementedError("Method not implemented!")
 
-    @abstractmethod
-    def _get_xp_module(self, array: xpArray = None) -> types.ModuleType:
+    def _get_xp_module(self, array: xpArray) -> types.ModuleType:
         """Returns the numpy-like module for a given array
 
         Parameters
@@ -142,10 +146,14 @@ class Backend(ABC):
         -------
         numpy-like module
         """
-        raise NotImplementedError("Method not implemented!")
+        try:
+            import cupy
 
-    @abstractmethod
-    def _get_sp_module(self, array: xpArray = None) -> types.ModuleType:
+            return cupy.get_array_module(array)
+        except ModuleNotFoundError:
+            return np
+
+    def _get_sp_module(self, array: xpArray) -> types.ModuleType:
         """Returns the scipy-like module for a given array
 
         Parameters
@@ -156,7 +164,66 @@ class Backend(ABC):
         -------
         scipy-like module
         """
-        raise NotImplementedError("Method not implemented!")
+        try:
+            import cupyx
+
+            return cupyx.scipy.get_array_module(array)
+        except ModuleNotFoundError:
+            import scipy
+
+            return scipy
+
+    def _get_skimage_submodule(self, submodule: str, array: xpArray) -> types.ModuleType:
+        """Returns the skimage-like module for a given array (skimage or cucim)
+
+        Parameters
+        ----------
+        array : xpArray, optional
+            Reference array
+        Returns
+        -------
+        types.ModuleType
+            skimage-like module
+        """
+
+        # avoiding try-catch
+        try:
+            import cupy
+
+            if isinstance(array, cupy.ndarray):
+                return importlib.import_module(f"cucim.skimage.{submodule}")
+        except ModuleNotFoundError:
+            return importlib.import_module(f"skimage.{submodule}")
+
+        return importlib.import_module(f"skimage.{submodule}")
 
     def synchronise(self) -> None:
         pass
+
+
+def _maybe_to_backend(backend: Backend, obj: Any) -> Any:
+
+    if isinstance(obj, np.ndarray):
+        # this must be first because arrays are iterables
+        return backend.to_backend(obj)
+
+    if isinstance(obj, Dict):
+        dispatch_data_to_backend(backend, [], obj)
+        return obj
+
+    elif isinstance(obj, (List, Tuple)):
+        obj = list(obj)
+        dispatch_data_to_backend(backend, obj, {})
+        return obj
+
+    else:
+        return obj
+
+
+def dispatch_data_to_backend(backend: Backend, args: Iterable, kwargs: Dict) -> None:
+    """Function to move arrays to backend INPLACE!"""
+    for i, v in enumerate(args):
+        args[i] = _maybe_to_backend(backend, v)
+
+    for k, v in kwargs.items():
+        kwargs[k] = _maybe_to_backend(backend, v)
