@@ -1,14 +1,14 @@
-import time
-
 from contextlib import contextmanager
 from time import time
 
+from arbol import aprint
+
 
 @contextmanager
-def timeit(description: str = '') -> None:
+def timeit(description: str = "") -> None:
     start = time()
     yield
     elapsed_time = time() - start
 
-    print(f"Elapsed time for '{description}': {elapsed_time} seconds")
+    aprint(f"Elapsed time for '{description}': {elapsed_time} seconds")
     return elapsed_time
